#ifndef FCCDA2BF_AF76_451E_9F7F_984C96EEF20B
#define FCCDA2BF_AF76_451E_9F7F_984C96EEF20B

#ifndef PRETTY_FUNCTION
    #if defined(__GNUC__) || (defined(__clang__) && !defined(_MSC_VER))
        #define PRETTY_FUNCTION __PRETTY_FUNCTION__
    #elif defined(_MSC_VER)
        #define PRETTY_FUNCTION __FUNCSIG__
    #else
        #define PRETTY_FUNCTION __func__
    #endif
#endif

#endif /* FCCDA2BF_AF76_451E_9F7F_984C96EEF20B */
